@@ -401,8 +401,8 @@
 #define LIBDIR_BASENAME "lib"
 #define HAVE__SETJMP 1
 #define HAVE_SIGSETJMP 1
-#define RUBY_SETJMP(env) __builtin_setjmp((void **)(env))
-#define RUBY_LONGJMP(env,val) __builtin_longjmp((void **)(env),val)
+#define RUBY_SETJMP(env) _setjmp((env))
+#define RUBY_LONGJMP(env,val) _longjmp((env),val)
 #define RUBY_JMP_BUF jmp_buf
 #define USE_MJIT 1
 #define HAVE_PTHREAD_H 1
