@@ -2,7 +2,7 @@
 #
 #   use-loader.rb -
 #   	$Release Version: 0.9.6$
-#   	$Revision: 53141 $
+#   	$Revision: 65505 $
 #   	by Keiju ISHITSUKA(keiju@ruby-lang.org)
 #
 # --
@@ -10,8 +10,8 @@
 #
 #
 
-require "irb/cmd/load"
-require "irb/ext/loader"
+require_relative "../cmd/load"
+require_relative "loader"
 
 class Object
   alias __original__load__IRB_use_loader__ load
